@@ -30,10 +30,6 @@ ONTOLOGY_RESOURCE = TESTS / "resources/fbbt.obo"
 SRC = Path(__file__).parent
 TOKEN_FILE = join(SRC, "token.txt")
 
-with open(TOKEN_FILE, "r") as t:
-    TOKEN = t.read().rstrip()
-
-g = Github(TOKEN)
 # Example for API: https://pygithub.readthedocs.io/en/latest/examples.html
 
 RAW_DATA = "_rawData"
@@ -55,6 +51,7 @@ ISSUE_KEYS = [
 
 def get_issues(
     repository_name: str,
+    token: str = None,
     title_search: Optional[str] = None,
     label: Optional[str] = None,
     number: Optional[int] = 0,
@@ -63,27 +60,36 @@ def get_issues(
     """Get issues of specific states from a Github repository.
 
     :param repository_name: Name of the repository [org/repo]
-    :param title_search: Regex for title of the issue.
+    :param token: Github token for authorization, defaults to None
+    :param title_search: Regex for title of the issue., defaults to None
+    :param label: Issue label, defaults to None
+    :param number: Issue number, defaults to 0
     :param state: State of the issue e.g. open, close etc., defaults to "open"
     :yield: Issue names that match the regex/label/number.
     """
+    if token is None:
+        token_file = TOKEN_FILE
+        with open(token_file, "r") as t:
+            token = t.read().rstrip()
+
+    g = Github(token)
     repo = g.get_repo(repository_name)
     label_object = None
     if label:
         label_object = repo.get_label(label)
-
-    issues = repo.get_issues(state=state)
-
-    for issue in issues:
-        if title_search is None and label_object is None and number == 0:
-            yield issue
-        else:
-            if title_search and re.match(title_search, issue.title):
+    if number and number > 0:
+        yield _extract_info_from_issue_object(repo.get_issue(number))
+    else:
+        issues = repo.get_issues(state=state)
+        for issue in issues:
+            if title_search is None and label_object is None and number == 0:
+                yield issue
+            elif title_search and re.match(title_search, issue.title):
                 yield _extract_info_from_issue_object(issue)
-            if label_object and label_object in issue.labels:
-                yield _extract_info_from_issue_object(issue)
-            if number and number == issue.number:
+            elif label_object and label_object in issue.labels:
                 yield _extract_info_from_issue_object(issue)
+            else:
+                yield None
 
 
 def _extract_info_from_issue_object(issue: Issue) -> dict:
@@ -107,12 +113,19 @@ def _make_sense_of_body(body: str) -> str:
     return body.replace("<", "").replace(">", "")
 
 
-def get_all_labels_from_repo(repository_name: str) -> dict:
+def get_all_labels_from_repo(repository_name: str, token: str = None) -> dict:
     """Get all labels available in a repository for tagging issues on creation.
 
     :param repository_name: Name of the repository.
+    :param token: Github token for authorization, defaults to None
     :return: A dictionary of {name: description}
     """
+    if token is None:
+        token_file = TOKEN_FILE
+        with open(token_file, "r") as t:
+            token = t.read().rstrip()
+
+    g = Github(token)
     repo = g.get_repo(repository_name)
     return {label.name: label.description for label in repo.get_labels()}
 
