@@ -51,6 +51,11 @@ repo_option = click.option(
     required=True,
     help="Org/name of the github repo.",
 )
+token_option = click.option(
+    "-g",
+    "--token",
+    help="Github token for the repository.",
+)
 
 issue_number_option = click.option(
     "-n",
@@ -88,10 +93,12 @@ output_option = click.option(
     "--title-search",
     help="Filter based on a search for pattern within title of issue.",
 )
+@token_option
 @label_option
 @issue_number_option
 def issues(
     repo: str,
+    token: str,
     state: str,
     title_search: str,
     label: str,
@@ -108,6 +115,7 @@ def issues(
     """
     for issue in get_issues(
         repository_name=repo,
+        token=token,
         state=state,
         title_search=title_search,
         label=label,
@@ -118,72 +126,83 @@ def issues(
 
 @main.command("get-labels")
 @repo_option
-def get_labels(repo: str):
+@token_option
+def get_labels(repo: str, token: str):
     """Get all labels for issues.
 
     :param repo: GitHub repository name [org/repo_name]
     """
-    print(get_all_labels_from_repo(repo))
+    print(get_all_labels_from_repo(repo, token))
 
 
 @main.command()
 @input_argument
 @repo_option
+@token_option
 @label_option
 @issue_number_option
 @state_option
 @output_option
-def process_issue(input: str, repo: str, label: str, number: int, state: str, output: str):
+def process_issue(
+    input: str, repo: str, token: str, label: str, number: int, state: str, output: str
+):
     """Run processes based on issue label.
 
     :param repo: GitHub repository name [org/repo_name]
     :param label: Label of issues.
     :param state: State of issue ["open", "close" etc.]
     """
-    formatted_body = "The following commands were executed: </br>"
+    formatted_body = "The following commands were executed: </br> "
 
-    for issue in get_issues(repository_name=repo, label=label, number=number, state=state):
+    for issue in get_issues(
+        repository_name=repo, token=token, label=label, number=number, state=state
+    ):
         # Make sure ontobot_change_agent needs to be triggered or no.
-        if re.match(r"(.*)ontobot(.*)apply(.*):(.*)", issue[BODY]):
-            bullet_starters = ["* ", "- "]
-            KGCL_COMMANDS = []
-            for bullet in bullet_starters:
+        if issue:
+            if re.match(r"(.*)ontobot(.*)apply(.*):(.*)", issue[BODY]):
+                bullet_starters = ["* ", "- "]
+                KGCL_COMMANDS = []
+                for bullet in bullet_starters:
 
-                KGCL_COMMANDS.extend(
-                    [
-                        str(item).replace(bullet, "")
-                        for item in issue[BODY].splitlines()
-                        if item.startswith(bullet)
-                    ]
-                )
-            if output:
-                new_output = output
+                    KGCL_COMMANDS.extend(
+                        [
+                            str(item).replace(bullet, "")
+                            for item in issue[BODY].splitlines()
+                            if item.startswith(bullet)
+                        ]
+                    )
+                if output:
+                    new_output = output
+                else:
+                    new_output = input
+
+                KGCL_COMMANDS = [x.strip() for x in KGCL_COMMANDS]
+                if issue["number"] == number and len(KGCL_COMMANDS) > 0:  # noqa W503  # noqa W503
+                    process_issue_via_oak(
+                        input=input,
+                        commands=KGCL_COMMANDS,
+                        output=new_output,
+                    )
+
+                    formatted_body += _list_to_markdown(KGCL_COMMANDS)
+                    formatted_body += "</br>Fixes #" + str(issue["number"])
+                    # TODO: remove `set-output` when env var setting is confirmed.
+                    if os.getenv("GITHUB_ENV"):
+                        with open(os.getenv("GITHUB_ENV"), "a") as env:  # type: ignore
+                            print(f"PR_BODY={formatted_body}", file=env)
+                            print(f"PR_TITLE={issue[TITLE]}", file=env)
+
+                    click.echo(
+                        f"""
+                        PR_BODY={formatted_body}
+                        PR_TITLE={issue[TITLE]}
+                        """
+                    )
             else:
-                new_output = input
-
-            KGCL_COMMANDS = [x.strip() for x in KGCL_COMMANDS]
-            if issue["number"] == number and len(KGCL_COMMANDS) > 0:  # noqa W503  # noqa W503
-                process_issue_via_oak(
-                    input=input,
-                    commands=KGCL_COMMANDS,
-                    output=new_output,
-                )
-
-                formatted_body += _list_to_markdown(KGCL_COMMANDS)
-                formatted_body += "</br>Fixes #" + str(issue["number"])
-                #TODO: remove `set-output` when env var setting is confirmed.
-                with open(os.getenv("GITHUB_ENV"), "a") as env:
-                    print(f"PR_BODY={formatted_body}", file=env)
-                    print(f"PR_TITLE={issue[TITLE]}", file=env)
-                    
-                click.echo(
-                    f"""
-                    ::set-output name=PR_BODY::{formatted_body}
-                    ::set-output name=PR_TITLE::{issue[TITLE]}
-                    """
-                )
+                click.echo(f"""{issue[TITLE]} does not need ontobot's attention.""")
         else:
-            click.echo(f"""{issue[TITLE]} does not need ontobot's attention.""")
+            click.echo(f"""Issue number:{number} is either closed or does not exist.""")
+            break
 
 
 def _list_to_markdown(list: list) -> str:
